==> haskell-wai-websockets-3.0.1.2-582-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-AG57hT7zjy8GEOjGlC2ywy
key:                  wai-websockets-3.0.1.2-AG57hT7zjy8GEOjGlC2ywy
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  9cc8f4373c5e6cfde4659ee850cc033d
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-AG57hT7zjy8GEOjGlC2ywy
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4P9iCjJMWMIHxNOvyaASZG
    http-types-0.12.4-3DQiCH8RwXkLA2zexb7ibB
    network-3.1.4.0-9G0x2c0R6cS5Adtb7MLWUj transformers-0.5.6.2
    wai-3.2.4-7gPy4vrA6McEXoAULdTry7
    websockets-0.12.7.3-H23qGrWuYb81Gt0FiAjmsE

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-583-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-2J4NFzQYDkn4TDAiqEUJSY
key:                  wai-websockets-3.0.1.2-2J4NFzQYDkn4TDAiqEUJSY
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  335b8bfd46d22a86c398099fc286c397
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-2J4NFzQYDkn4TDAiqEUJSY
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Dv0qc5eM6SdL4nJsx4bnK
    http-types-0.12.4-1OQw2FrAjtsGCePB2Q8s8s
    network-3.1.4.0-9SQkdFTpEbMLQxc4pkijnN transformers-0.5.6.2
    wai-3.2.4-F2VJAE8OhtyI4jBCcdCBBc
    websockets-0.12.7.3-HJ3s1y5CRasCFnVvcZpUIW

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
